#!/bin/bash

echo "***************************************"
echo "BOUSI-PROLOG v1.4 uninstallation script"
echo "***************************************"

# Checks if Bousi-Prolog is installed for all users
# and root wants to uninstall it
if [ -f /usr/bin/bousi ] && [ $UID -eq 0 ]; then
	# Reads installation directory from launching script "/usr/bin/bousi"
	LINE=`cat /usr/bin/bousi | grep "BPL_INSDIR="`
	if [ -n "$LINE" ]; then
		BPL_INSDIR=`echo $LINE | cut -c 12-`
		echo
		echo "Bousi-Prolog is installed for all users in $BPL_INSDIR."
		echo -n "All contents of this directory will be erased. Do you want to continue? "
		read -n 1 OPTION
		echo
		if [ "$OPTION" = "Y" ] || [ "$OPTION" = "y" ]; then
			# Erases the folder where the program is installed
			echo
			echo "Erasing $BPL_INSDIR..."
			rm -R $BPL_INSDIR
			# Removes the script "/usr/bin/bousi"
			echo
			echo "Removing Bousi-Prolog launching script in /usr/bin..."
			rm -f /usr/bin/bousi
			UNINSTALLED=1
		else
			UNINSTALLED=0
		fi
	else
		# Installation directory can't be found
		UNINSTALLED=-2
	fi
else
	# Checks if Bousi-Prolog is installed for this user
	if [ -n "$BPL_INSDIR" ] && [ -f $HOME/.bplrc ]; then
		echo
		echo "Bousi-Prolog is currently installed at $BPL_INSDIR."
		echo -n "All contents of this directory will be erased. Do you want to continue? "
		read -n 1 OPTION
		echo
		if [ "$OPTION" = "Y" ] || [ "$OPTION" = "y" ]; then
			# Erases the folder where the program is installed
			echo
			echo "Erasing $BPL_INSDIR..."
			rm -R $BPL_INSDIR
			# Removes the initialization file ".bplrc" from home directory
			echo
			echo "Removing Bousi-Prolog initialization files..."
			rm -f $HOME/.bplrc
			# Modifies the ".bashrc" file to remove Bousi-Prolog initialization
			sed -i~ -e "/^. \$HOME\/.bplrc/d; /^# Bousi-Prolog initialization/d" $HOME/.bashrc
			BPL_INSDIR=
			UNINSTALLED=1
		else
			UNINSTALLED=0
		fi
	else
		# Bousi-Prolog is not installed
		UNINSTALLED=-1
	fi
fi

if [ $UNINSTALLED -eq 0 ]; then
	echo
	echo "Bousi-Prolog has NOT been uninstalled."
elif [ $UNINSTALLED -eq 1 ]; then
	echo
	echo "Bousi-Prolog has been uninstalled."
elif [ $UNINSTALLED -eq -1 ]; then
	echo
	echo "Bousi-Prolog doesn't seem to be installed in this system,"
	echo "or you don't have enough privileges to uninstall it."
elif [ $UNINSTALLED -eq -2 ]; then
	echo
	echo "Bousi-Prolog installation directory couldn't be found."
	echo "Uninstallation script will now exit."
fi

